# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""add std_cal qa_fail action

Revision ID: 3cc6bd75e664
Revises: 22db21f0ecb2
Create Date: 2021-10-27 09:48:23.508181

"""
from alembic import op

# revision identifiers, used by Alembic.
revision = "3cc6bd75e664"
down_revision = "22db21f0ecb2"
branch_labels = None
depends_on = None


def upgrade():
    """
    add action for standard calibration QA fail
    Add standard calibration QA failure
    to capability_state_transitions table

    :return:
    """
    op.execute(
        """
        INSERT INTO capability_state_transitions (capability_name, from_state, to_state, pattern)
        VALUES ('std_calibration', 'Awaiting QA', 'Failed', 'type == qa-fail')
        """
    )
    op.execute(
        """
        INSERT INTO capability_state_actions (transition_id, arguments, action_type)
            VALUES (
            (SELECT transition_id FROM capability_state_transitions
                WHERE capability_name='std_calibration'
                AND from_state='Awaiting QA'
                AND to_state='Failed'), 'qa_fail', 'ExecuteWorkflow'
        )
        """
    )


def downgrade():
    """
    remove action for standard calibration QA fail
    Remove standard calibration QA failure
    from capability_state_transitions table
    :return:
    """
    op.execute(
        """
        DELETE FROM capability_state_transitions
        WHERE capability_name='std_calibration'
        AND from_state='Awaiting QA'
        AND to_state='Failed'
        AND pattern='type == qa-fail'
        """
    )
    op.execute(
        """
        DELETE FROM capability_state_actions
        WHERE action_type='ExecuteWorkflow'
        AND arguments='qa_fail'
        AND transition_id=
        (SELECT transition_id
        FROM capability_state_transitions
        WHERE capability_name='std_calibration'
        AND from_state='Awaiting QA'
        AND to_state='Failed')
        """
    )
